Documentation
¶
Overview ¶
Package mapstructenv provides a decode hook function that replaces the raw value with an environment variable value under the same key.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnvReplacerHookFunc ¶
func EnvReplacerHookFunc() mapstructure.DecodeHookFuncType
EnvReplacerHookFunc returns a hook function that tries to replace the raw value with an environment variable value under the same key. An environment variable is a string that starts with "${" and ends with "}", e.g. "${SOME_CONFIGURATION_KEY}". If the environment variable does not exist, the raw value is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.